Reproducible figures and tables from paper — xsmc 1.0.4.dev3+g6ae67c3.d20201023 documentation

# Reproducible figures and tables from paper

The notebooks below can be used to reproduce the figures and tables contained in the manuscript and supplement.

Note: These pages are automatically regenerated on each commit. Over time, accumulated changes to the codebase may cause the minor differences to emerge between the published figures and what is contained in these notebooks. To access the exact version of the code that was used to generate the published figures, use the git commit tag paper.

User guide

- Exact SMC Simulations
- Bayesian vs MAP
- Linear time complexity
- Li-Stephens vs Exact Decoding
- Comparison of XSMC and PSMC
- 1000 Genomes analysis